bypass property
bool
get
bypass
A bypass of the validation rules with this option. This option is ideal to avoid checking their validity.
Implementation
bool get bypass;
A bypass of the validation rules with this option. This option is ideal to avoid checking their validity.
bool get bypass;